@@ -1,7 +1,6 @@
-use crate::{Context, Message};
+use crate::{util::ui_util::AppStyle, Context, Message};
 use serde::{Deserialize, Serialize};
 use std::{collections::HashMap, env, fs, path::Path};
-use crate::util::ui_util::AppStyle;
 
 pub type KeyConfig = HashMap<Context, HashMap<String, Message>>;
 pub type ThemeConfig = HashMap<AppStyle, String>;
