@@ -1,4 +1,4 @@
-use crate::{util::ui_util::StatefulTable, App, MPDConnection};
+use crate::{data_types::ListEntrySelector, util::ui_util::StatefulTable, App, MPDConnection};
 use mpd::{Query, Song, Term};
 
 #[derive(Debug, Clone)]
@@ -45,34 +45,45 @@ impl LibraryModel {
         }
     }
 
-    fn get_next_state(&self) -> Option<State> {
-        if let Some(index) = self.items.state.selected() {
-            if let Some(selected) = self.items.items.get(index) {
-                let state = self.state.clone();
-                return Some(match state {
-                    Artists => Artist(Selection(index, selected.clone())),
-                    Artist(artist) => Album(artist, Selection(index, selected.clone())),
-                    Album(ar, al) => Song(ar, al, Selection(index, selected.clone())),
-                    Song(ar, al, so) => Song(ar, al, so),
-                });
-            }
+    fn get_next_state(&self, selector: &ListEntrySelector) -> Option<State> {
+        if let Some(selected) = self.items.item_from_selector(selector) {
+            let index = self.items.index_from_selector(selector);
+            let state = self.state.clone();
+            return Some(match state {
+                Artists => Artist(Selection(index, selected.clone())),
+                Artist(artist) => Album(artist, Selection(index, selected.clone())),
+                Album(ar, al) => Song(ar, al, Selection(index, selected.clone())),
+                Song(ar, al, so) => Song(ar, al, so),
+            });
         }
 
         None
     }
 }
 
-pub fn play(app: &App) {
-    let state = app.model().library.get_next_state();
+fn enqueue(app: &App, replace: bool, selector: &ListEntrySelector) {
+    let state = app.model().library.get_next_state(selector);
 
     let mut connection = app.connection();
     if let Some(next_state) = state {
-        let _ = connection.clear();
+        if replace {
+            let _ = connection.clear();
+        }
         queue_add(&mut connection, next_state);
-        let _ = connection.play();
+        if replace {
+            let _ = connection.play();
+        }
     }
 }
 
+pub fn play(app: &App, selector: &ListEntrySelector) {
+    enqueue(app, true, selector)
+}
+
+pub fn add_to_queue(app: &App, selector: &ListEntrySelector) {
+    enqueue(app, false, selector)
+}
+
 fn queue_add(connection: &mut MPDConnection, next_state: State) {
     match next_state {
         Artists => {
@@ -129,6 +140,28 @@ fn list(app: &App, term: &str, query_tag: &str, query_value: &str) {
     app.model().library.items = StatefulTable::with_items(list);
 }
 
+fn find_songs(app: &App, album_name: &str) {
+    let mut query = Query::new();
+    let query = query.and(mpd::Term::Tag("Album".into()), album_name.to_string());
+    let mut list = app
+        .connection()
+        .find(&query, None)
+        .unwrap_or_else(|_| Vec::new());
+
+    list.sort_by_key(|song| {
+        song.tags
+            .get("Track")
+            .cloned()
+            .map(|t| t.parse::<u32>().unwrap())
+    });
+
+    app.model().library.items = StatefulTable::with_items(
+        list.iter()
+            .map(|song| song.clone().title.unwrap_or(song.file.clone()))
+            .collect(),
+    );
+}
+
 fn find_song(
     connection: &mut MPDConnection,
     album_name: String,
@@ -144,25 +177,24 @@ fn find_song(
         .map(|songs| songs.first().unwrap().clone())
 }
 
-pub fn update(app: &App) {
-    let state = app.model().library.state.clone();
+fn update_list(app: &App, state: &State) {
     match state {
         Artists => list_all(&app, "AlbumArtist"),
         Artist(artist) => list(&app, "Album", "Artist", &artist.1),
-        Album(_, album) => list(&app, "Title", "Album", &album.1),
+        Album(_, album) => find_songs(&app, &album.1),
         Song(_, _, song) => list(&app, "Title", "Title", &song.1),
     }
 }
 
-pub fn state_down(app: &App) {
-    let state = app.model().library.get_next_state();
+pub fn update(app: &App) {
+    let state = app.model().library.state.clone();
+    update_list(app, &state);
+}
+
+pub fn state_down(app: &App, selector: &ListEntrySelector) {
+    let state = app.model().library.get_next_state(selector);
     if let Some(state) = state {
-        match state.clone() {
-            Artists => list_all(&app, "AlbumArtist"),
-            Artist(artist) => list(&app, "Album", "Artist", &artist.1),
-            Album(_, album) => list(&app, "Title", "Album", &album.1),
-            Song(_, _, song) => list(&app, "Title", "Title", &song.1),
-        };
+        update_list(app, &state.clone());
 
         app.model().library.state = state;
     }
@@ -187,12 +219,7 @@ pub fn state_up(app: &App) {
         }
     };
 
-    match next_state.clone() {
-        Artists => list_all(&app, "AlbumArtist"),
-        Artist(artist) => list(&app, "Album", "Artist", &artist.1),
-        Album(_, album) => list(&app, "Title", "Album", &album.1),
-        Song(_, _, song) => list(&app, "Title", "Title", &song.1),
-    };
+    update_list(app, &next_state);
 
     let mut library = &mut app.model().library;
     library.state = next_state;
