@@ -1,3 +1,4 @@
+pub mod input;
 pub mod library;
 pub mod playlists;
 pub mod progress_bar;
@@ -11,6 +12,7 @@ use strum_macros::{EnumIter, EnumString, IntoStaticStr};
 
 use crate::{data_types::*, util::ui_util::TabsState, Config, Keys};
 
+pub use input::InputModel;
 pub use library::LibraryModel;
 pub use playlists::PlaylistsModel;
 pub use progress_bar::ProgressBarModel;
@@ -75,6 +77,7 @@ pub struct Model {
 
     pub progress_bar: ProgressBarModel,
     pub volume: VolumeModel,
+    pub input: InputModel,
 
     pub tabs: TabsState,
 
@@ -91,9 +94,10 @@ impl Model {
             playlists: PlaylistsModel::new(),
             progress_bar: ProgressBarModel::new(),
             volume: VolumeModel::new(),
+            input: InputModel::new(),
             tabs: create_tabs(),
             keys: Keys::new(&config),
-            input_state: InputState::None,
+            input_state: InputState::KeyCommands,
             loading: 0,
         }
     }
