@@ -1,4 +1,4 @@
-use crate::{util::ui_util::StatefulTable, App};
+use crate::{data_types::ListEntrySelector, util::ui_util::StatefulTable, App};
 use mpd::Playlist;
 
 #[derive(Debug, Clone)]
@@ -20,18 +20,27 @@ impl PlaylistsModel {
     }
 }
 
-pub fn play(app: &App) {
+pub fn play(app: &App, selector: &ListEntrySelector) {
     let mut connection = app.connection();
 
     connection
         .clear()
         .ok()
-        .and_then(|_| app.model().playlists.items.state.selected())
-        .and_then(|index| app.model().playlists.items.items.get(index).cloned())
+        .and_then(|_| {
+            app.model()
+                .playlists
+                .items
+                .item_from_selector(selector)
+                .cloned()
+        })
         .and_then(|playlist| connection.load(playlist, ..).ok())
         .and_then(|_| connection.play().ok());
 }
 
+pub fn save(app: &App, name: &str) {
+    let _ = app.connection().save(name); // TODO
+}
+
 pub fn update(app: &App) {
     let playlists = app.connection().playlists();
 
