@@ -57,10 +57,11 @@ impl ProgressBarModel {
 
 pub fn update(app: &App) {
     let mut connection = app.connection();
-    if let Ok(status) = connection.status() {
-        if let Ok(Some(song)) = connection.currentsong() {
-            let mut progress_bar = &mut app.model().progress_bar;
 
+    if let Ok(status) = connection.status() {
+        let mut progress_bar = &mut app.model().progress_bar;
+
+        if let Ok(Some(song)) = connection.currentsong() {
             progress_bar.state = match status.state {
                 State::Play | State::Pause => {
                     let text = match status.state {
@@ -90,6 +91,11 @@ pub fn update(app: &App) {
                 progress_bar.elapsed = elapsed;
                 progress_bar.duration = duration;
             }
+        } else {
+            progress_bar.state = "Stopped".to_string();
+            progress_bar.playing = false;
+            progress_bar.elapsed = Duration::zero();
+            progress_bar.duration = Duration::zero();
         }
     } else {
         app.model().progress_bar.state = "Error".into();
