@@ -1,4 +1,4 @@
-use crate::{util::ui_util::StatefulTable, App};
+use crate::{data_types::*, util::ui_util::StatefulTable, App};
 use mpd::Song;
 
 #[derive(Debug, Clone)]
@@ -22,11 +22,11 @@ impl QueueModel {
     }
 }
 
-pub fn play(app: &App) {
-    let selected = app.model().queue.items.state.selected();
+pub fn play(app: &App, entry: &ListEntrySelector) {
+    let selected = app.model().queue.items.index_from_selector(entry);
 
     // Lock on model is released, so we can lock connection
-    selected.and_then(|s| app.connection().switch(s as u32).ok());
+    let _ = app.connection().switch(selected as u32);
 }
 
 pub fn update(app: &App) {
