@@ -28,7 +28,7 @@ pub fn update(app: &App) {
         .map(|status| update_state_volume(app, status));
 }
 
-fn set_volume(app: &App, new_volume: i8) {
+pub fn set_volume(app: &App, new_volume: i8) {
     let mut connection = app.connection();
     if let Ok(()) = connection.volume(new_volume) {
         app.model().volume.volume = new_volume;
