@@ -1,8 +1,4 @@
-use crate::{
-    model::LibraryModel,
-    util::ui_util,
-    AppBackend, ThemeConfig,
-};
+use crate::{model::LibraryModel, util::ui_util, AppBackend, ThemeConfig};
 
 use tui::{
     layout::{Constraint, Rect},
