@@ -1,3 +1,4 @@
+mod input;
 mod library;
 mod playlists;
 mod progress_bar;
@@ -68,8 +69,10 @@ impl View {
             }
 
             match &model.input_state {
-                InputState::TextInput => {}
-                InputState::None => {
+                InputState::TextInput => {
+                    input::view(&mut model.input, &theme, f, chunks[2]);
+                }
+                InputState::KeyCommands => {
                     progress_bar::view(&model.progress_bar, &theme, f, chunks[2]);
                 }
             }
