@@ -1,8 +1,4 @@
-use crate::{
-    model::PlaylistsModel,
-    util::ui_util,
-    AppBackend, ThemeConfig,
-};
+use crate::{model::PlaylistsModel, util::ui_util, AppBackend, ThemeConfig};
 
 use mpd::Playlist;
 use tui::{
