@@ -4,11 +4,7 @@ use crate::{
     AppBackend, ThemeConfig,
 };
 
-use tui::{
-    layout::Rect,
-    terminal::Frame,
-    widgets::Gauge,
-};
+use tui::{layout::Rect, terminal::Frame, widgets::Gauge};
 
 pub fn view(
     progress_bar: &ProgressBarModel,
